(async function (drupalSettings) {
  // Function to run a test.
  async function runTest(testId) {
    // Add a promise.
    return new Promise((resolve, reject) => {
      // Set the test ID to running.
      let testStatusElement = document.querySelector('.test-status-' + testId);
      if (testStatusElement) {
        testStatusElement.innerHTML = 'running...';
      }
      let testIdElement = document.querySelector('.test-' + testId);
      if (testIdElement) {
        testIdElement.classList.add('running');
      }
      let testDetailsElement = document.querySelector('.test-details-' + testId);
      // Start a test on the ajax endpoint.
      let id = drupalSettings.agentTestGroup.testGroupResultId;
      let provider = encodeURIComponent(drupalSettings.agentTestGroup.providerId);
      let model = encodeURIComponent(drupalSettings.agentTestGroup.modelId);
      fetch(drupalSettings.path.baseUrl + 'admin/content/ai-agents-test/group/run/ajax/' + testId + '/' + id + '?provider_id=' + provider + '&model_id=' + model)
      .then(function (response) {
        // Check if the response is ok.
        if (!response.ok) {
          testIdElement.classList.add('error');
          testIdElement.classList.remove('running');
          testStatusElement.innerHTML = 'error';
          throw new Error('Network response was not ok');
        }
        // Get the response as JSON.
        return response.json();
      })
      .then(function (data) {
        // Check if the test was successful.
        if (data.success) {
          testIdElement.classList.add('success');
          testIdElement.classList.remove('running');
          testStatusElement.innerHTML = 'success';
          let link = drupalSettings.path.baseUrl + 'admin/content/ai-agents-test/result/' + data.entity;
          let linkText = '<a href="' + link + '" target="_blank">' + Drupal.t('View result') + '</a>';
          testDetailsElement.innerHTML = linkText;
        }
        else {
          // If the test failed, add the error class.
          testIdElement.classList.add('error');
          testIdElement.classList.remove('running');
          testStatusElement.innerHTML = 'error';
        }
        resolve();
      })
      .catch(function (error) {
        console.error('Error:', error);
        testIdElement.classList.add('error');
        testIdElement.classList.remove('running');
        testStatusElement.innerHTML = 'error';
        // Resolve the promise.
        resolve();
      });
    });
  }

  // Synchronously run all the tests in the group.
  for (let testId of drupalSettings.agentTestGroup.testsToStart) {
    await runTest(testId);
  }
  // Forward to the result page.
  let id = drupalSettings.agentTestGroup.testGroupResultId;
  let url = drupalSettings.path.baseUrl + 'admin/content/ai-agents-test/group/result/' + id;
  window.location.replace(url);
})(drupalSettings);
