<?php

declare(strict_types=1);

namespace Drupal\ai_agents_test\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\ai\AiProviderPluginManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form controller for preparing the group run.
 */
final class PrepareAgentTestGroupRunForm extends FormBase {

  /**
   * Constructs a new PrepareAgentTestGroupRunForm object.
   */
  public function __construct(
    protected AiProviderPluginManager $aiProvider,
    protected EntityTypeManagerInterface $entityTypeManager,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('ai.provider'),
      $container->get('entity_type.manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'ai_agents_test_group_run_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    // Get the group ID from the query string.
    $group_id = $this->getRequest()->query->get('group_id');
    // Add so you can pick the provider/model.
    $models = $this->aiProvider->getSimpleProviderModelOptions('chat');
    // Get the default provider.
    $defaults = $this->aiProvider->getSimpleDefaultProviderOptions('chat_with_tools');

    // Get all the test groups.
    $test_groups = $this->entityTypeManager->getStorage('ai_agents_test_group')->loadMultiple();
    $test_groups_options = [];
    foreach ($test_groups as $test_group) {
      $test_groups_options[$test_group->id()] = $test_group->label();
    }
    $form['test_group'] = [
      '#type' => 'select',
      '#title' => $this->t('Test group'),
      '#options' => $test_groups_options,
      '#description' => $this->t('Select the test group you want to run.'),
      '#required' => TRUE,
      '#default_value' => $group_id,
    ];

    $form['model'] = [
      '#type' => 'select',
      '#title' => $this->t('Model'),
      '#options' => $models,
      '#description' => $this->t('Select the model you want to use.'),
      '#required' => TRUE,
      '#default_value' => $defaults,
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Start a new test run'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $parts = explode('__', $form_state->getValue('model'));
    // We redirect to the test group runner.
    $form_state->setRedirect('ai_agents_test.run_test_group', [
      'group_id' => $form_state->getValue('test_group'),
    ], [
      'query' => [
        'provider_id' => $parts[0],
        'model_id' => $parts[1],
      ],
    ]);
  }

}
