<?php

namespace Drupal\ai_agents_test\Traits;

use Drupal\ai\OperationType\Chat\ChatInput;
use Drupal\ai\OperationType\Chat\ChatMessage;
use Drupal\ai\OperationType\Chat\Tools\ToolsFunctionInput;
use Drupal\ai\OperationType\Chat\Tools\ToolsInput;
use Drupal\ai\OperationType\Chat\Tools\ToolsPropertyInput;

/**
 * Trait for testing using LLM.
 */
trait LlmTestTrait {

  /**
   * Test using LLM.
   *
   * @param string $test_prompt
   *   The test prompt to use.
   * @param string $value
   *   The value to test against.
   *
   * @return array
   *   The results of the test.
   */
  public function testUsingLlm(string $test_prompt, string $value): array {
    // Get the AI provider.
    $defaults = \Drupal::service('ai.provider')->getSetProvider('chat_with_tools');
    // Create a tool - we do manually, so no tool needs to exist.
    $functions[] = new ToolsFunctionInput('test_results', [
      'description' => 'Test the results.',
      'properties' => [
        new ToolsPropertyInput('result', [
          'description' => 'The result of the test. Should be a string, TRUE or FALSE.',
          'type' => 'string',
          'enum' => [
            'TRUE',
            'FALSE',
          ],
        ]),
        new ToolsPropertyInput('reasoning', [
          'description' => 'The reasoning behind the result.',
          'type' => 'string',
        ]),
      ],
    ]);

    $prompt = "
      You are a test runner for AI agents. You will be given a prompt and a value. The prompt tests the value. You will return the result of the test using the tool.

      The prompt is: $test_prompt

      The value is: $value
    ";
    $input = new ChatInput([
      new ChatMessage('user', $prompt),
    ]);
    $input->setChatTools(new ToolsInput($functions));

    $response = $defaults['provider_id']->chat($input, $defaults['model_id'], [
      'ai_agents_test_runner_result',
    ]);
    $normalized = $response->getNormalized();
    $tools = $normalized->getTools();
    if (!isset($tools[0])) {
      return [
        'result' => FALSE,
        'reasoning' => 'The LLM could not verify anything.',
      ];
    }
    $arguments = $tools[0]->getArguments();
    $return = [
      'result' => FALSE,
      'reasoning' => 'The LLM could not verify anything.',
    ];
    foreach ($arguments as $argument) {
      if ($argument->getName() === 'result') {
        $return['result'] = $argument->getValue() == FALSE || $argument->getValue() == 'FALSE' ? FALSE : TRUE;
      }
      elseif ($argument->getName() === 'reasoning') {
        $return['reasoning'] = $argument->getValue();
      }
    }
    return $return;
  }

}
